==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/s3/kotlin/inputs/BucketReplicationConfigRuleSourceSelectionCriteriaSseKmsEncryptedObjectsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.s3.kotlin.inputs

import com.pulumi.aws.s3.inputs.BucketReplicationConfigRuleSourceSelectionCriteriaSseKmsEncryptedObjectsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property status Whether the existing objects should be replicated. Either `"Enabled"` or `"Disabled"`.
 */
public data class BucketReplicationConfigRuleSourceSelectionCriteriaSseKmsEncryptedObjectsArgs(
    public val status: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.s3.inputs.BucketReplicationConfigRuleSourceSelectionCriteriaSseKmsEncryptedObjectsArgs> {
    override fun toJava():
        com.pulumi.aws.s3.inputs.BucketReplicationConfigRuleSourceSelectionCriteriaSseKmsEncryptedObjectsArgs =
        com.pulumi.aws.s3.inputs.BucketReplicationConfigRuleSourceSelectionCriteriaSseKmsEncryptedObjectsArgs.builder()
            .status(status.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [BucketReplicationConfigRuleSourceSelectionCriteriaSseKmsEncryptedObjectsArgs].
 */
@PulumiTagMarker
public class BucketReplicationConfigRuleSourceSelectionCriteriaSseKmsEncryptedObjectsArgsBuilder
internal constructor() {
    private var status: Output<String>? = null

    /**
     * @param value Whether the existing objects should be replicated. Either `"Enabled"` or `"Disabled"`.
     */
    @JvmName("kylatnllmulmpjrm")
    public suspend fun status(`value`: Output<String>) {
        this.status = value
    }

    /**
     * @param value Whether the existing objects should be replicated. Either `"Enabled"` or `"Disabled"`.
     */
    @JvmName("hjvolfsnlxjvfebm")
    public suspend fun status(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.status = mapped
    }

    internal fun build(): BucketReplicationConfigRuleSourceSelectionCriteriaSseKmsEncryptedObjectsArgs =
        BucketReplicationConfigRuleSourceSelectionCriteriaSseKmsEncryptedObjectsArgs(
            status = status ?: throw PulumiNullFieldException("status"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/s3/kotlin/inputs/BucketReplicationConfigRuleSourceSelectionCriteriaSseKmsEncryptedObjectsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.s3.kotlin.inputs

import com.pulumi.aws.s3.inputs.BucketReplicationConfigRuleSourceSelectionCriteriaSseKmsEncryptedObjectsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property status Whether the existing objects should be replicated. Either `"Enabled"` or `"Disabled"`.
 */
public data class BucketReplicationConfigRuleSourceSelectionCriteriaSseKmsEncryptedObjectsArgs(
    public val status: Output<String>,
) :
    ConvertibleToJava<com.pulumi.aws.s3.inputs.BucketReplicationConfigRuleSourceSelectionCriteriaSseKmsEncryptedObjectsArgs> {
    override fun toJava(): com.pulumi.aws.s3.inputs.BucketReplicationConfigRuleSourceSelectionCriteriaSseKmsEncryptedObjectsArgs =
        com.pulumi.aws.s3.inputs.BucketReplicationConfigRuleSourceSelectionCriteriaSseKmsEncryptedObjectsArgs.builder()
            .status(status.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [BucketReplicationConfigRuleSourceSelectionCriteriaSseKmsEncryptedObjectsArgs].
 */
@PulumiTagMarker
public class BucketReplicationConfigRuleSourceSelectionCriteriaSseKmsEncryptedObjectsArgsBuilder
internal constructor() {
    private var status: Output<String>? = null

    /**
     * @param value Whether the existing objects should be replicated. Either `"Enabled"` or `"Disabled"`.
     */
    @JvmName("uoitmcahpidjrtva")
    public suspend fun status(`value`: Output<String>) {
        this.status = value
    }

    /**
     * @param value Whether the existing objects should be replicated. Either `"Enabled"` or `"Disabled"`.
     */
    @JvmName("nyvwnlyefwsfeoem")
    public suspend fun status(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.status = mapped
    }

    internal fun build(): BucketReplicationConfigRuleSourceSelectionCriteriaSseKmsEncryptedObjectsArgs = BucketReplicationConfigRuleSourceSelectionCriteriaSseKmsEncryptedObjectsArgs(
        status = status ?: throw PulumiNullFieldException("status"),
    )
}
